OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Fjalëkalimi ështe një nga 1,000,000 më të përdorshmit. Ju lutem krijojeni atë unik.",
    "Password needs to contain at least one numeric character." : "Fjalëkali duhet të përmbajë të paktën një karakter numerik.",
    "Password needs to contain at least one special character." : "Fjalëkalimi duhet të përmbajë të paktën një karakter special.",
    "Password needs to contain at least one lower and one upper case character." : "Fjalëkalimi duhet të përmbajë të paktën një karakter me shkronja të vogla dhe një karakter me shkronja të mëdhaja.",
    "Password policy" : "Politika e fjalëkalimit ",
    "Forbid common passwords" : "Ndalo fjalëkalimet e zakonshme",
    "Enforce upper and lower case characters" : "Detyro karakteret me shkronjë të madhe dhe të vogël",
    "Enforce numeric characters" : "Detyro karakteret numerike ",
    "Enforce special characters" : "Detyro karakteret e veçanta",
    "Unknown error" : "Gabim i panjohur",
    "Settings saved" : "Opsjonet u Ruajtën."
},
"nplurals=2; plural=(n != 1);");
